@@ -1,4 +1,4 @@
-/* $OpenBSD: enc.c,v 1.37 2014/07/12 17:54:31 jsing Exp $ */
+/* $OpenBSD: enc.c,v 1.38 2014/07/14 00:35:10 deraadt Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -600,17 +600,13 @@ end:
 	ERR_print_errors(bio_err);
 	free(strbuf);
 	free(buff);
-	if (in != NULL)
-		BIO_free(in);
+	BIO_free(in);
 	if (out != NULL)
 		BIO_free_all(out);
-	if (benc != NULL)
-		BIO_free(benc);
-	if (b64 != NULL)
-		BIO_free(b64);
+	BIO_free(benc);
+	BIO_free(b64);
 #ifdef ZLIB
-	if (bzl != NULL)
-		BIO_free(bzl);
+	BIO_free(bzl);
 #endif
 	free(pass);
 
