@@ -1,4 +1,5 @@
 #!/bin/sh
 set -e
-export PATH=../apps:$PATH
+PATH=../apps:$PATH
+export PATH
 $srcdir/testssl $srcdir/server.pem $srcdir/server.pem $srcdir/ca.pem
